

The Tendril Framework
=====================

.. image:: https://badge.fury.io/py/tendril-framework.png
    :target: http://badge.fury.io/py/tendril-framework

.. image:: https://travis-ci.org/chintal/tendril.png?branch=master
    :target: https://travis-ci.org/chintal/tendril

.. image:: https://coveralls.io/repos/chintal/tendril/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/chintal/tendril?branch=master

.. image:: https://landscape.io/github/chintal/tendril/master/landscape.svg?style=flat
    :target: https://landscape.io/github/chintal/tendril/master

An open-ended framework for handling information, to aid development, management, and production cycles

